@@ -318,7 +318,7 @@ fit_multi_feature_models <- function(data, test_method, use_balanced_accuracy, u
   
   if(use_empirical_null){
     
-    if(null_testing_method == "null model fits"){
+    if(null_testing_method == "NullModelFits"){
       
       # Set up progress bar for {purrr::map} iterations
       
@@ -365,7 +365,7 @@ calculate_multivariable_statistics <- function(data, set = NULL, p_value_method,
   
   if(!is.null(set)){
     vals <- data %>%
-      dplyr::filter(.data$method %in% c(set, "model free shuffles"))
+      dplyr::filter(.data$method %in% c(set, "ModelFreeShuffles"))
   } else{
     vals <- data
   }
@@ -577,7 +577,11 @@ clean_by_set <- function(data, themethod = NULL){
   tmp_cleaner <- tmp_cleaner %>%
     janitor::clean_names() %>%
     tidyr::pivot_longer(cols = 3:ncol(tmp_cleaner), names_to = "names", values_to = "values") %>%
-    dplyr::mutate(method = gsub("_.*", "\\1", .data$names)) %>%
+    dplyr::mutate(method = gsub("_.*", "\\1", .data$names),
+                  method = dplyr::case_when(
+                    .data$method == "tsfel" ~ "TSFEL",
+                    .data$method == "kats"  ~ "Kats",
+                    TRUE                    ~ method)) %>%
     dplyr::mutate(group = as.factor(.data$group)) %>%
     dplyr::mutate(group = as.integer(.data$group),
                   group = paste0("Group_", .data$group),
@@ -634,7 +638,7 @@ clean_by_set <- function(data, themethod = NULL){
 #'   use_k_fold = TRUE,
 #'   num_folds = 10,
 #'   use_empirical_null = TRUE,
-#'   null_testing_method = "model free shuffles",
+#'   null_testing_method = "ModelFreeShuffles",
 #'   p_value_method = "gaussian",
 #'   num_permutations = 50,
 #'   seed = 123)
@@ -644,7 +648,7 @@ clean_by_set <- function(data, themethod = NULL){
 fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group",
                                          by_set = FALSE, test_method = "gaussprRadial",
                                          use_balanced_accuracy = FALSE, use_k_fold = TRUE, num_folds = 10,
-                                         use_empirical_null = FALSE, null_testing_method = c("model free shuffles", "null model fits"),
+                                         use_empirical_null = FALSE, null_testing_method = c("ModelFreeShuffles", "NullModelFits"),
                                          p_value_method = c("empirical", "gaussian"), num_permutations = 100, seed = 123){
   
   #---------- Check arguments ------------
@@ -677,23 +681,33 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
   
   # Null testing options
   
-  theoptions <- c("model free shuffles", "null model fits")
+  theoptions <- c("ModelFreeShuffles", "NullModelFits")
+  
+  if(null_testing_method == "model free shuffles"){
+    message("'model free shuffles' is deprecated, please use 'ModelFreeShuffles' instead.")
+    null_testing_method <- "ModelFreeShuffles"
+  }
+  
+  if(null_testing_method == "null model fits"){
+    message("'null model fits' is deprecated, please use 'NullModelFits' instead.")
+    null_testing_method <- "NullModelFits"
+  }
   
   if(is.null(null_testing_method) || missing(null_testing_method)){
-    null_testing_method <- "model free shuffles"
-    message("No argument supplied to null_testing_method. Using 'model free shuffles' as default.")
+    null_testing_method <- "ModelFreeShuffles"
+    message("No argument supplied to null_testing_method. Using 'ModelFreeShuffles' as default.")
   }
   
   if(length(null_testing_method) != 1){
-    stop("null_testing_method should be a single string of either 'model free shuffles' or 'null model fits'.")
+    stop("null_testing_method should be a single string of either 'ModelFreeShuffles' or 'NullModelFits'.")
   }
   
   if(null_testing_method %ni% theoptions){
-    stop("null_testing_method should be a single string of either 'model free shuffles' or 'null model fits'.")
+    stop("null_testing_method should be a single string of either 'ModelFreeShuffles' or 'NullModelFits'.")
   }
   
-  if(null_testing_method == "model free shuffles" && num_permutations < 1000){
-    message("Null testing method 'model free shuffles' is fast. Consider running more permutations for more reliable results. N = 10000 is recommended.")
+  if(null_testing_method == "ModelFreeShuffles" && num_permutations < 1000){
+    message("Null testing method 'ModelFreeShuffles' is fast. Consider running more permutations for more reliable results. N = 10000 is recommended.")
   }
   
   # p-value options
@@ -778,6 +792,11 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
     
     data_id <- unique(data_id$method) %>%
       purrr::map_df(~ clean_by_set(data = data_id, themethod = .x))
+    
+    # Create reference set for all feature aggregation option
+    
+    data_id_all <- clean_by_set(data = data_id, themethod = NULL)
+    
   } else{
     message("Assessing feature values and unique IDs for NAs using matrix of all features.")
     data_id <- clean_by_set(data = data_id, themethod = NULL)
@@ -795,7 +814,7 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
   
   # Very important coffee console message
   
-  if(null_testing_method == "null model fits" & num_permutations > 50){
+  if(null_testing_method == "ModelFreeShuffles" & num_permutations > 50){
     message("This will take a while. Great reason to go grab a coffee and relax ^_^")
   }
   
@@ -817,6 +836,21 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
                                                set = .x,
                                                seed = seed))
     
+    output_all <- fit_multi_feature_models(data = data_id_all,
+                                           test_method = test_method,
+                                           use_balanced_accuracy = use_balanced_accuracy,
+                                           use_k_fold = use_k_fold,
+                                           num_folds = num_folds,
+                                           use_empirical_null = use_empirical_null,
+                                           null_testing_method = null_testing_method,
+                                           num_permutations = num_permutations,
+                                           set = NULL,
+                                           seed = seed) %>%
+      dplyr::mutate(method = "All features") %>%
+      dplyr::mutate(num_features_used = length(unique(data_id_all$names)))
+    
+    output <- dplyr::bind_rows(output, output_all)
+    
   } else{
     
     output <- fit_multi_feature_models(data = data_id,
@@ -833,7 +867,7 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
   
   # Run nulls if random shuffles are to be used
   
-  if(null_testing_method == "model free shuffles"){
+  if(null_testing_method == "ModelFreeShuffles"){
     
     # Run random shuffles procedure
     
@@ -844,7 +878,7 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
     
     nullOuts <- simulate_null_acc(x = x_prep, num_permutations = num_permutations, use_balanced_accuracy = use_balanced_accuracy) %>%
       dplyr::mutate(category = "Null",
-                    method = "model free shuffles",
+                    method = "ModelFreeShuffles",
                     num_features_used = NA)
     
     if(use_k_fold){
@@ -864,6 +898,20 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
   
   if(by_set){
     
+    # Get chance probability
+    
+    chance <- round((1 / length(unique(data_id$group)) * 100), digits = 2)
+    
+    # Define colour palette
+    
+    mypal <- c("catch22" = "#1B9E77",
+               "feasts" = "#D95F02",
+               "Kats" = "#7570B3",
+               "tsfeatures" = "#E7298A",
+               "TSFEL" = "#66A61E",
+               "tsfresh" = "#E6AB02",
+               "All features" = "grey50")
+    
     #--------------
     # Draw bar plot
     #--------------
@@ -923,21 +971,23 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
     # Draw plot
     
     accuracies <- accuracies %>%
-      dplyr::mutate(statistic = .data$statistic * 100)
+      dplyr::mutate(statistic = .data$statistic * 100) %>%
+      dplyr::mutate(method_short = gsub(" .*", "\\1", .data$method))
     
     if(use_k_fold){
       
       accuracies <- accuracies %>%
         mutate(statistic_sd = .data$statistic_sd * 100) %>%
-        dplyr::mutate(lower = .data$statistic - (2 * .data$statistic_sd),
-                      upper = .data$statistic + (2 * .data$statistic_sd))
+        dplyr::mutate(lower = .data$statistic - (1 * .data$statistic_sd),
+                      upper = .data$statistic + (1 * .data$statistic_sd))
       
       FeatureSetResultsPlot <- accuracies %>%
-        ggplot2::ggplot(ggplot2::aes(x = stats::reorder(.data$method, -.data$statistic))) +
-        ggplot2::geom_bar(ggplot2::aes(y = .data$statistic, fill = .data$method), stat = "identity") +
-        ggplot2::geom_errorbar(ggplot2::aes(ymin = .data$lower, ymax = .data$upper), colour = "black")
+        ggplot2::ggplot(ggplot2::aes(x = reorder(.data$method, -.data$statistic), y = .data$statistic, colour = .data$method_short)) +
+        ggplot2::geom_hline(yintercept = chance, colour = "black", lty = "dashed", size = 1) +
+        ggplot2::geom_point(size = 5) +
+        ggplot2::geom_errorbar(ggplot2::aes(ymin = .data$lower, ymax = .data$upper), size = 1)
       
-      # Expand y axis if max (mean + (2*SD)) is > 100%
+      # Expand y-axis if max (mean + (1*SD)) is > 100%
       
       if(max(accuracies$upper, na.rm = TRUE) >= 100){
         
@@ -955,14 +1005,15 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
       }
       
       FeatureSetResultsPlot <- FeatureSetResultsPlot +
-        ggplot2::labs(subtitle = "Number of features is indicated in parentheses. Error bars are +/- 2 times SD")
+        ggplot2::labs(subtitle = "Number of features is indicated in parentheses. Error bars are +/- 1 times SD. Dashed line = chance")
       
     } else{
       
       FeatureSetResultsPlot <- accuracies %>%
-        ggplot2::ggplot(ggplot2::aes(x = stats::reorder(.data$method, -.data$statistic))) +
-        ggplot2::geom_bar(ggplot2::aes(y = .data$statistic, fill = .data$method), stat = "identity") +
-        ggplot2::labs(subtitle = "Number of features is indicated in parentheses") +
+        ggplot2::ggplot(ggplot2::aes(x = stats::reorder(.data$method, -.data$statistic), colour = .data$method_short)) +
+        ggplot2::geom_hline(yintercept = chance, colour = "black", lty = "dashed", size = 1) +
+        ggplot2::geom_point(size = 5) +
+        ggplot2::labs(subtitle = "Number of features is indicated in parentheses. Dashed line = chance") +
         ggplot2::scale_y_continuous(limits = c(0, 100),
                                     breaks = seq(from = 0, to = 100, by = 20),
                                     labels = function(x) paste0(x, "%"))
@@ -972,9 +1023,10 @@ fit_multi_feature_classifier <- function(data, id_var = "id", group_var = "group
       ggplot2::labs(title = "Classification accuracy by feature set",
                     y = "Classification accuracy (%)",
                     x = "Feature set",
-                    fill = NULL) +
+                    fill = NULL,
+                    colour = NULL) +
+      ggplot2::scale_colour_manual(values = mypal) +
       ggplot2::theme_bw() +
-      ggplot2::scale_fill_brewer(palette = "Dark2") +
       ggplot2::theme(panel.grid.minor = ggplot2::element_blank(),
                      legend.position = "none",
                      axis.text.x = ggplot2::element_text(angle = 90, hjust = 1))
